
#ifndef KPEOPLEWIDGETS_EXPORT_H
#define KPEOPLEWIDGETS_EXPORT_H

#ifdef KPEOPLEWIDGETS_STATIC_DEFINE
#  define KPEOPLEWIDGETS_EXPORT
#  define KPEOPLEWIDGETS_NO_EXPORT
#else
#  ifndef KPEOPLEWIDGETS_EXPORT
#    ifdef KF6PeopleWidgets_EXPORTS
        /* We are building this library */
#      define KPEOPLEWIDGETS_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KPEOPLEWIDGETS_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KPEOPLEWIDGETS_NO_EXPORT
#    define KPEOPLEWIDGETS_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KPEOPLEWIDGETS_DECL_DEPRECATED
#  define KPEOPLEWIDGETS_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KPEOPLEWIDGETS_DECL_DEPRECATED_EXPORT
#  define KPEOPLEWIDGETS_DECL_DEPRECATED_EXPORT KPEOPLEWIDGETS_EXPORT KPEOPLEWIDGETS_DECL_DEPRECATED
#endif

#ifndef KPEOPLEWIDGETS_DECL_DEPRECATED_NO_EXPORT
#  define KPEOPLEWIDGETS_DECL_DEPRECATED_NO_EXPORT KPEOPLEWIDGETS_NO_EXPORT KPEOPLEWIDGETS_DECL_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KPEOPLEWIDGETS_NO_DEPRECATED
#    define KPEOPLEWIDGETS_NO_DEPRECATED
#  endif
#endif
#include <kpeople_version.h>

#define KPEOPLEWIDGETS_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

/* Take any defaults from group settings */
#if !defined(KPEOPLEWIDGETS_NO_DEPRECATED) && !defined(KPEOPLEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  ifdef KF_NO_DEPRECATED
#    define KPEOPLEWIDGETS_NO_DEPRECATED
#  elif defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#    define KPEOPLEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  endif
#endif
#if !defined(KPEOPLEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT) && defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  define KPEOPLEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#endif

#if !defined(KPEOPLEWIDGETS_NO_DEPRECATED_WARNINGS) && !defined(KPEOPLEWIDGETS_DEPRECATED_WARNINGS_SINCE)
#  ifdef KF_NO_DEPRECATED_WARNINGS
#    define KPEOPLEWIDGETS_NO_DEPRECATED_WARNINGS
#  elif defined(KF_DEPRECATED_WARNINGS_SINCE)
#    define KPEOPLEWIDGETS_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#  endif
#endif
#if !defined(KPEOPLEWIDGETS_DEPRECATED_WARNINGS_SINCE) && defined(KF_DEPRECATED_WARNINGS_SINCE)
#  define KPEOPLEWIDGETS_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#endif

#if defined(KPEOPLEWIDGETS_NO_DEPRECATED)
#  undef KPEOPLEWIDGETS_DEPRECATED
#  define KPEOPLEWIDGETS_DEPRECATED_EXPORT KPEOPLEWIDGETS_EXPORT
#  define KPEOPLEWIDGETS_DEPRECATED_NO_EXPORT KPEOPLEWIDGETS_NO_EXPORT
#elif defined(KPEOPLEWIDGETS_NO_DEPRECATED_WARNINGS)
#  define KPEOPLEWIDGETS_DEPRECATED
#  define KPEOPLEWIDGETS_DEPRECATED_EXPORT KPEOPLEWIDGETS_EXPORT
#  define KPEOPLEWIDGETS_DEPRECATED_NO_EXPORT KPEOPLEWIDGETS_NO_EXPORT
#else
#  define KPEOPLEWIDGETS_DEPRECATED KPEOPLEWIDGETS_DECL_DEPRECATED
#  define KPEOPLEWIDGETS_DEPRECATED_EXPORT KPEOPLEWIDGETS_DECL_DEPRECATED_EXPORT
#  define KPEOPLEWIDGETS_DEPRECATED_NO_EXPORT KPEOPLEWIDGETS_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define KPEOPLEWIDGETS_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define KPEOPLEWIDGETS_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef KPEOPLEWIDGETS_NO_DEPRECATED
#  define KPEOPLEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT KPEOPLE_VERSION
#endif
#ifdef KPEOPLEWIDGETS_NO_DEPRECATED_WARNINGS
#  define KPEOPLEWIDGETS_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef KPEOPLEWIDGETS_DEPRECATED_WARNINGS_SINCE
#  ifdef KPEOPLEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define KPEOPLEWIDGETS_DEPRECATED_WARNINGS_SINCE KPEOPLEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define KPEOPLEWIDGETS_DEPRECATED_WARNINGS_SINCE KPEOPLE_VERSION
#  endif
#endif

#ifndef KPEOPLEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define KPEOPLEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef KPEOPLEWIDGETS_DEPRECATED
#  define KPEOPLEWIDGETS_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KPEOPLEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define KPEOPLEWIDGETS_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#endif /* KPEOPLEWIDGETS_EXPORT_H */
